@@ -2,6 +2,7 @@ import os
 import yaml
 import math
 import logging
+import requests
 from typing import *
 
 import torch
@@ -35,18 +36,24 @@ class TamingDecoder(ImageGenerator):
 
         modeling_ckpt_path = os.path.join(modeling_cache_dir, 'last.ckpt')
         if not os.path.exists(modeling_ckpt_path):
-            logging.info("Downloading pre-trained weights for VQ-GAN")
-            os.system(
-                f"curl -LO 'https://heibox.uni-heidelberg.de/f/867b05fc8c4841768640/?dl=1' -o '{modeling_ckpt_path}'"
-            )
+            modeling_ckpt_url = 'https://heibox.uni-heidelberg.de/f/867b05fc8c4841768640/?dl=1'
+            
+            logging.info(f"Downloading pre-trained weights for VQ-GAN from {modeling_ckpt_url}")
+            results = requests.get(modeling_ckpt_url, allow_redirects=True)
+
+            with open(modeling_ckpt_path, "wb") as ckpt_file:
+                ckpt_file.write(results.content)
 
         # TODO: update the url with our own config using the correct paths
         modeling_config_path = os.path.join(modeling_cache_dir, 'model.yaml')
         if not os.path.exists(modeling_config_path):
+            modeling_config_url = 'https://raw.githubusercontent.com/vipermu/taming-transformers/master/configs/custom_vqgan.yaml'
+            
             logging.info("Downloading `model.yaml` from vipermu taming-transformers fork")
-            os.system(
-                f"curl -LO 'https://raw.githubusercontent.com/vipermu/taming-transformers/master/configs/custom_vqgan.yaml' -o '{modeling_config_path}'"
-            )
+            results = requests.get(modeling_config_url, allow_redirects=True)
+
+            with open(modeling_config_path, "wb") as yaml_file:
+                yaml_file.write(results.content)
 
         vqgan_config_xl = self.load_config(
             config_path=modeling_config_path,
